@@ -51,7 +51,7 @@ def get_local_file(model):
 	for i in range(len(data)):
 		try:
 			data[i] = data[i].split(": ")
-			print(Fore.RED+data[i][0]+": "+Fore.GREEN+data[i][1]+"\n")
+			print(Fore.RED+data[i][0]+": "+Fore.GREEN+data[i][1]+"\n"+Fore.RESET)
 		except:
 			pass
 
